.. _trojanzoo.models:

models
=======

.. currentmodule:: trojanzoo.models

.. autofunction:: add_argument
.. autofunction:: create
.. autofunction:: output_available_models

.. autoclass:: Model
   :members:
   :private-members: _train, _validate

.. autoclass:: _Model
   :members:

